documentationtools.make_text_alignment_example_lilypond_file
============================================================

.. autofunction:: abjad.tools.documentationtools.make_text_alignment_example_lilypond_file.make_text_alignment_example_lilypond_file
